/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03393
 |               DRUG SERVICES RESEARCH SURVEY (DSRS), 1990
 |           (DATASET 0002: PHASE II - ADMINISTRATOR INTERVIEW)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03393-0002-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE q1_cor    -9='(-9) NOT ASCERTAINED' 1='(1) YES' 2='(2) NO' ;
  VALUE q2ffffff  -9='(-9) NOT ASCERTAINED' 1='(1) DRUG ONLY' 2='(2) ALCOHOL ONLY'
                  3='(3) BOTH DRUG AND ALCOHOL' ;
  VALUE q3_sep    -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX BOTH DRUG AND ALCOHOL CLIENTS'
                  1='(1) YES' 2='(2) NO' ;
  VALUE q4_dif    -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX BOTH DRUG AND ALCOHOL CLIENTS'
                  1='(1) YES' 2='(2) NO' ;
  VALUE q5_drug   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - BOTH DRUG & ALC CLIENTS NOT TX OR NOT SEPARATED'
                  1='(1) DRUG PROTOCOL DESCRIBED' ;
  VALUE q5_alc    -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - BOTH DRUG & ALC CLIENTS NOT TX OR NOT SEPARATED'
                  1='(1) ALCOHOL PROTOCOL DESCRIBED' ;
  VALUE q6_cor    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q6a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - FIGURE FROM TELEPHONE INT IS CORRECT' ;
  VALUE q7_cor    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q7a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - FIGURE FROM TELEPHONE INT IS CORRECT' 0='(0) NONE' ;
  VALUE q8ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' ;
  VALUE q9ffffff  -9='(-9) NOT ASCERTAINED - MISSING' -8='(-8) DON''T KNOW' 1='(1) MORE'
                  2='(2) LESS' 3='(3) ABOUT THE SAME' ;
  VALUE q10a_hdd  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_hdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDD' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_hdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDD' ;
  VALUE q10a_hdf  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_hdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDF' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_hdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDF' ;
  VALUE q10a_rdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_rdd  -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDD' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_rdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDD' ;
  VALUE q10a_rdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_rdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDF' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_rdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDF' ;
  VALUE q10a_odd  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_odd  -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODD' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_odd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODD' ;
  VALUE q10a_odm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_odm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODM' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_odm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODM' ;
  VALUE q10a_odf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_odf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODF' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_odf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODF' ;
  VALUE q11_hdd   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDD'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_hdf   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDF'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_rdd   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDD'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_rdf   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDF'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_odd   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODD'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_odm   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODM'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_odf   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODF'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q12a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q12b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q12c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q12d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES (SPECIFY)'
                  2='(2) NO' ;
  VALUE q13a      1='(1) YES' 2='(2) NO' ;
  VALUE q13a_tns  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX TEENS' 1='(1) YES' 2='(2) NO' ;
  VALUE q13b      -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q13b_prg  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX PREGNANT WOMEN' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q13c      -9='(-9) NOT ASCERTAINED' 1='(1) YES' 2='(2) NO' ;
  VALUE q13c_ivd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX IV DRUG USERS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q13d      -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q13d_ddc  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX DUAL DX PXS' 1='(1) YES' 2='(2) NO' ;
  VALUE q13e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q14a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q14b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q14c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q15_cert  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q15a      -9='(-9) NOT ASCERRTAINED'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COUNSELORS W/ SPECIAL CERTS'
                  1='(1) DESCRIPTION OF SPECIAL CERTIFICATION GIVEN' ;
  VALUE q16_comp  1='(1) YES' 2='(2) NO' ;
  VALUE q17a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q17b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q17c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q17d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q18_own   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) PUBLICLY OWNED'
                  2='(2) PRIVATELY OWNED, NON-PROFIT'
                  3='(3) PRIVATELY OWNED, FOR PROFIT' ;
  VALUE q19a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19f      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES (SPECIFY)'
                  2='(2) NO' ;
  VALUE q20a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q20b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q20c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES (SPECIFY)'
                  2='(2) NO' ;
  VALUE q21_othu  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q22_mult  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q23a_1ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_2ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_3ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_4ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_5ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_1ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_2ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_3ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_4ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_5ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23c_1ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23c_2ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23c_3ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE corrfac   0='(0) NO' 1='(1) YES' ;
  VALUE alchonly  0='(0) NO' 1='(1) YES' ;
  VALUE stratum   1='(1) HOSPITAL IN-PATIENT DRUG TREATMENT'
                  2='(2) RESIDENTIAL DRUG TREATMENT'
                  3='(3) OUT-PATIENT DRUG DETOXIFICATION MAINTENANCE'
                  4='(4) OUT-PATIENT DRUG-FREE TREATMENT'
                  5='(5) ALCOHOL TREATMENT ONLY' 6='(6) UNKNOWN TREATMENT TYPE' ;
  VALUE region    1='(1) NORTHEAST' 2='(2) NORTH CENTRAL' 3='(3) SOUTH' 4='(4) WEST' ;
  VALUE qa1fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa1a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA1' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa2fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa3fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa3a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA3' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa4fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa4a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA4' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa5fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa5a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 2, 8 OR 9 IN QA5' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa6fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa6a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 2, 8 OR 9 IN QA6A' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qb1fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qb1a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QB1' 1='(1) YES'
                  2='(2) NO' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=444;
INPUT
        CASEID 1-3              OBS_NUM 4-6             Q1_COR 7
        Q2 8                    Q3_SEP 9-10             Q4_DIF 11-12
        Q5_DRUG 13-14           Q5_ALC 15-16            Q6_COR 17-18
        Q6A 19-21               Q7_COR 22-23            Q7A 24-26
        Q8 27-29                Q9 30-31                Q10A_HDD 32
        Q10B_HDD 33-34          Q10C_HDD 35-36          Q10A_HDF 37
        Q10B_HDF 38-39          Q10C_HDF 40-41          Q10A_RDD 42-43
        Q10B_RDD 44-45          Q10C_RDD 46-47          Q10A_RDF 48
        Q10B_RDF 49-50          Q10C_RDF 51-52          Q10A_ODD 53
        Q10B_ODD 54-55          Q10C_ODD 56-57          Q10A_ODM 58
        Q10B_ODM 59-60          Q10C_ODM 61-63          Q10A_ODF 64-65
        Q10B_ODF 66-67          Q10C_ODF 68-69          Q11_HDD 70-71
        Q11_HDF 72-73           Q11_RDD 74-75           Q11_RDF 76-77
        Q11_ODD 78-79           Q11_ODM 80-81           Q11_ODF 82-83
        Q12A 84                 Q12B 85                 Q12C 86
        Q12D 87                 Q13A 88                 Q13A_TNS 89-90
        Q13B 91-92              Q13B_PRG 93-94          Q13C 95-96
        Q13C_IVD 97-98          Q13D 99-100             Q13D_DDC 101-102
        Q13E 103-104            Q14A 105                Q14B 106
        Q14C 107                Q15_CERT 108-109        Q15A 110-111
        Q16_COMP 112            Q17A 113-114            Q17B 115-116
        Q17C 117-118            Q17D 119-120            Q18_OWN 121
        Q19A 122                Q19B 123-124            Q19C 125
        Q19D 126-127            Q19E 128-129            Q19F 130-131
        Q20A 132                Q20B 133-134            Q20C 135-136
        Q21_OTHU 137            Q22_MULT 138            Q23A_1 139-140
        Q23A_2 141-142          Q23A_3 143-144          Q23A_4 145-146
        Q23A_5 147-148          Q23B_1 149-150          Q23B_2 151-152
        Q23B_3 153-154          Q23B_4 155-156          Q23B_5 157-158
        Q23C_1 159-160          Q23C_2 161-162          Q23C_3 163-164
        CORRFAC 165             ALCHONLY 166            STRATUM 167
        REGION 168              QA1 169-170             QA1A 171-172
        QA2 173-174             QA3 175-176             QA3A 177-178
        QA4 179-180             QA4A 181-182            QA5 183-184
        QA5A 185-186            QA6 187-188             QA6A 189-190
        QB1 191-192             QB1A 193-194            REP_STRA 195-196
        VWGHT 197-204 .5        VWT1 205-212 .5         VWT2 213-220 .5
        VWT3 221-228 .5         VWT4 229-236 .5         VWT5 237-244 .5
        VWT6 245-252 .5         VWT7 253-260 .5         VWT8 261-268 .5
        VWT9 269-276 .5         VWT10 277-284 .5        VWT11 285-292 .5
        VWT12 293-300 .5        VWT13 301-308 .5        VWT14 309-316 .5
        VWT15 317-324 .5        VWT16 325-332 .5        VWT17 333-340 .5
        VWT18 341-348 .5        VWT19 349-356 .5        VWT20 357-364 .5
        VWT21 365-372 .5        VWT22 373-380 .5        VWT23 381-388 .5
        VWT24 389-396 .5        VWT25 397-404 .5        VWT26 405-412 .5
        VWT27 413-420 .5        VWT28 421-428 .5        VWT29 429-436 .5
        VWT30 437-444 .5        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   OBS_NUM = 'OBSERVATION NUMBER'
   Q1_COR  = '1. IS UNIT NAME FROM SURVEY CORRECT?'
   Q2      = '2. DRUG/ALCOHOL CLIENTS TREATED?'
   Q3_SEP  = '3. DRUG & ALCOHOL CLIENTS SEPERATED?'
   Q4_DIF  = '4. DIFFERENT TREATMENT DRUG/ALCOHOL ?'
   Q5_DRUG = '5. DESCRIBE DRUG PROTOCOL:'
   Q5_ALC  = '5. DESCRIBE ALCOHOL PROTOCOL:'
   Q6_COR  = '6. TOTAL CAPACITY CORRECT:'
   Q6A     = '6A. TOTAL CAPACITY ON MARCH 30 WAS:'
   Q7_COR  = '7. # OF CLIENTS IN TREATMENT CORRECT?'
   Q7A     = '8. ACTUAL # OF CLIENTS ON MARCH 30:'
   Q8      = '8. # OF CLIENTS IN TREATMENT TODAY:'
   Q9      = '9. CLIENTS ON MAR 30 COMPARED TO TODAY:'
   Q10A_HDD= '10A. DOES UNIT OFFER HIDD TREATMENT?'
   Q10B_HDD= '10B. WAITING LIST POLICY FOR HIDD?'
   Q10C_HDD= '10C. # OF CLIENTS - HIDD WAITING LIST:'
   Q10A_HDF= '10A. DOES UNIT OFFER HIDF TREATMENT?'
   Q10B_HDF= '10B. WAITING LIST POLICY FOR HIDF?'
   Q10C_HDF= '10C. # OF CLIENTS - HIDF WAITING LIST:'
   Q10A_RDD= '10A. DOES UNIT OFFER RDD TREATMENT?'
   Q10B_RDD= '10B. WAITING LIST POLICY FOR RDD?'
   Q10C_RDD= '10C. # OF CLIENTS - RDD WAITING LIST:'
   Q10A_RDF= '10A. DOES UNIT OFFER RDF TREATMENT?'
   Q10B_RDF= '10B. WAITING LIST POLICY FOR RDF?'
   Q10C_RDF= '10C. # OF CLIENTS - RDF WAITING LIST:'
   Q10A_ODD= '10A. DOES UNIT OFFER OPDD TREATMENT?'
   Q10B_ODD= '10B. WAITING LIST POLICY FOR OPDD?'
   Q10C_ODD= '10C. # OF CLIENTS - OPDD WAITING LIST:'
   Q10A_ODM= '10A. DOES UNIT OFFER OPDM TREATMENT?'
   Q10B_ODM= '10B. WAITING LIST POLICY FOR OPDM?'
   Q10C_ODM= '10C. # OF CLIENTS - OPDM WAITING LIST:'
   Q10A_ODF= '10A. DOES UNIT OFFER OPDF TREATMENT?'
   Q10B_ODF= '10B. WAITING LIST POLICY FOR OPDF?'
   Q10C_ODF= '10C. # OF CLIENTS - OPDF WAITING LIST:'
   Q11_HDD = '11. HIDD WAITING LIST POLICY DESCRIBED:'
   Q11_HDF = '11. HIDF WAITING LIST POLICY DESCRIBED:'
   Q11_RDD = '11. RDD WAITING LIST POLICY DESCRIBED:'
   Q11_RDF = '11. RDF WAITING LIST POLICY DESCRIBED:'
   Q11_ODD = '11. OPDD WAITING LIST POLICY DESCRIBED:'
   Q11_ODM = '11. OPDM WAITING LIST POLICY DESCRIBED:'
   Q11_ODF = '11. OPDF WAITING LIST POLICY DESCRIBED:'
   Q12A    = '12A. OFFER SPECIAL PROGRAMS TO BLACKS?'
   Q12B    = '12B. OFFER SPECIAL PROGS TO HISPANICS?'
   Q12C    = '12C. OFFER SPECIAL PROGS TO NATIVE AM?'
   Q12D    = '12D. OFFER SPECIAL PROGRAMS TO OTHERS?'
   Q13A    = '13A. OFFER TREATMENT TO TEENS?'
   Q13A_TNS= '13A. OFFER PROGRAMS TO TEENS?'
   Q13B    = '13B. OFFER TREATMENT TO PREGNANT WOMEN?'
   Q13B_PRG= '13B. OFFER PROGRAMS TO PREGNANT WOMEN?'
   Q13C    = '13C. OFFER TREATMENT TO IV DRUG USERS?'
   Q13C_IVD= '13C. OFFER PROGRAMS TO IV DRUG USERS?'
   Q13D    = '13D. OFFER TREATMENT TO DUAL DX CLIENT?'
   Q13D_DDC= 'O13D. OFFER PROGRAM TO DUAL DX CLIENTS?'
   Q13E    = '13E. OFFER TREATMENT TO PEOPLE W/AIDS?'
   Q14A    = '14A. OFFER PROGRAMS TO COCAINE USERS?'
   Q14B    = '14B. OFFER PROGRAMS TO CRACK USERS?'
   Q14C    = '14C. OFFER PROGRAMS TO POLYDRUG USERS?'
   Q15_CERT= '15. DRUG COUNSELOR CERTIFICATION:'
   Q15A    = '15A. DESCRIBE SPECIAL CERTIFICATION:'
   Q16_COMP= '16. COMPUTERIZED SYSTEM FOR RECORDS:'
   Q17A    = '17A. INFO IN COMPUTER - DEMOGRAPHIC?'
   Q17B    = '17B. INFO IN COMPUTER - TREATMENT?'
   Q17C    = '17C. INFO IN COMPUTER - LAB RESULTS?'
   Q17D    = '17D. INFO IN COMPUTER - BILLING?'
   Q18_OWN = '18. IS THE SERVICE UNIT PRIMARILY:'
   Q19A    = '19A. UNIT LICENSED BY STATE AGENCY?'
   Q19B    = '19B. UNIT LICENSED BY COUNTY AGENCY?'
   Q19C    = '19C. UNIT LICENSED BY CITY AGENCY?'
   Q19D    = '19D. UNIT LICENSED BY FDA?'
   Q19E    = '19E. UNIT LICENSED BY DEA?'
   Q19F    = '19F. LICENSED BY OTHER ORGANIZATION?'
   Q20A    = '20A. UNIT ACCREDITED BY JCAHO?'
   Q20B    = '20B. UNIT ACCREDITED BY CARF?'
   Q20C    = '20C. UNIT ACCREDITED BY OTHER?'
   Q21_OTHU= '21. OTHER DRUG/ALC UNIT AT ADDRESS?'
   Q22_MULT= '22. MULTI-SITE DRUG/ALC FACILITY?'
   Q23A_1  = '23A. AN ORGANIZATION CHART PROVIDED:'
   Q23A_2  = '23A. STAFF LIST W/TITLE & DEGREES:'
   Q23A_3  = '23A. PROGRAM DESCRIPTION PROVIDED:'
   Q23A_4  = '23A. METHADONE TREATMENT PLAN PROVIDED:'
   Q23A_5  = '23A. TABLE OF CONTENTS FOR MANUALS:'
   Q23B_1  = '23B. ADMISSION CRITERIA PROVIDED:'
   Q23B_2  = '23B. WAITING LIST POLICY PROVIDED:'
   Q23B_3  = '23B. FEE SCHEDULES PROVIDED:'
   Q23B_4  = '23B. EXAMPLE OF CLIENT BILL PROVIDED:'
   Q23B_5  = '23B. ANNUAL BUDGET PROVIDED:'
   Q23C_1  = '23C. BLANK FORMS PROVIDED:'
   Q23C_2  = '23C. ROUTINE REPORT FROM MIS SYSTEM:'
   Q23C_3  = '23C. ANNUAL REPORT PROVIDED:'
   CORRFAC = 'CORRECTIONAL FACILITY'
   ALCHONLY= 'ALCOHOL ONLY FACILITY'
   STRATUM = 'STRATUM - SAMPLING FRAME'
   REGION  = 'REGION - CENSUS REGION'
   QA1     = 'A1. DISCHARGE CLIENTS - 9/1/89-8/31/90:'
   QA1A    = 'A1A. CAN THESE CLIENTS BE ADDED?'
   QA2     = 'A2. CLIENTS DISCHARGED MORE THAN ONCE:'
   QA3     = 'A3. CLIENTS WHO DIED IN TREATMENT:'
   QA3A    = 'A3A. CAN THESE CLIENTS BE ADDED?'
   QA4     = 'A4. CLIENTS DID NOT COMPLETE TREATMENT:'
   QA4A    = 'A4A. CAN THESE CLIENTS BE ADDED?'
   QA5     = 'A5. CLIENTS ADMIT/DISCHARGE SAME DAY:'
   QA5A    = 'A5A. IDENTIFY & EXCLUDED?'
   QA6     = 'A6.  CLIENTS ADMIT/DISCH W/O TREATMENT:'
   QA6A    = 'A6A. IDENTIFY & EXCLUDED?'
   QB1     = 'B1. DISCHARGE DATE REFER TO UNIT?'
   QB1A    = 'B1A. IDENTIFY AND EXCLUDED?'
   REP_STRA= 'REPLICATE GROUP'
   VWGHT   = 'FIN NONRESPONS ADJUSTED VISITATION WGT'
   VWT1    = 'REPLICATE WEIGHT 1'
   VWT2    = 'REPLICATE WEIGHT 2'
   VWT3    = 'REPLICATE WEIGHT 3'
   VWT4    = 'REPLICATE WEIGHT 4'
   VWT5    = 'REPLICATE WEIGHT 5'
   VWT6    = 'REPLICATE WEIGHT 6'
   VWT7    = 'REPLICATE WEIGHT 7'
   VWT8    = 'REPLICATE WEIGHT 8'
   VWT9    = 'REPLICATE WEIGHT 9'
   VWT10   = 'REPLICATE WEIGHT 10'
   VWT11   = 'REPLICATE WEIGHT 11'
   VWT12   = 'REPLICATE WEIGHT 12'
   VWT13   = 'REPLICATE WEIGHT 13'
   VWT14   = 'REPLICATE WEIGHT 14'
   VWT15   = 'REPLICATE WEIGHT 15'
   VWT16   = 'REPLICATE WEIGHT 16'
   VWT17   = 'REPLICATE WEIGHT 17'
   VWT18   = 'REPLICATE WEIGHT 18'
   VWT19   = 'REPLICATE WEIGHT 19'
   VWT20   = 'REPLICATE WEIGHT 20'
   VWT21   = 'REPLICATE WEIGHT 21'
   VWT22   = 'REPLICATE WEIGHT 22'
   VWT23   = 'REPLICATE WEIGHT 23'
   VWT24   = 'REPLICATE WEIGHT 24'
   VWT25   = 'REPLICATE WEIGHT 25'
   VWT26   = 'REPLICATE WEIGHT 26'
   VWT27   = 'REPLICATE WEIGHT 27'
   VWT28   = 'REPLICATE WEIGHT 28'
   VWT29   = 'REPLICATE WEIGHT 29'
   VWT30   = 'REPLICATE WEIGHT 30'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (OBS_NUM <= -1) THEN OBS_NUM = .;
   IF (Q1_COR <= -1) THEN Q1_COR = .;
   IF (Q2 <= -1) THEN Q2 = .;
   IF (Q3_SEP <= -1) THEN Q3_SEP = .;
   IF (Q4_DIF <= -1) THEN Q4_DIF = .;
   IF (Q5_DRUG <= -1) THEN Q5_DRUG = .;
   IF (Q5_ALC <= -1) THEN Q5_ALC = .;
   IF (Q6_COR <= -1) THEN Q6_COR = .;
   IF (Q6A <= -1) THEN Q6A = .;
   IF (Q7_COR <= -1) THEN Q7_COR = .;
   IF (Q7A <= -1) THEN Q7A = .;
   IF (Q8 <= -1) THEN Q8 = .;
   IF (Q9 <= -1) THEN Q9 = .;
   IF (Q10A_HDD <= -1) THEN Q10A_HDD = .;
   IF (Q10B_HDD <= -1) THEN Q10B_HDD = .;
   IF (Q10C_HDD <= -1) THEN Q10C_HDD = .;
   IF (Q10A_HDF <= -1) THEN Q10A_HDF = .;
   IF (Q10B_HDF <= -1) THEN Q10B_HDF = .;
   IF (Q10C_HDF <= -1) THEN Q10C_HDF = .;
   IF (Q10A_RDD <= -1) THEN Q10A_RDD = .;
   IF (Q10B_RDD <= -1) THEN Q10B_RDD = .;
   IF (Q10C_RDD <= -1) THEN Q10C_RDD = .;
   IF (Q10A_RDF <= -1) THEN Q10A_RDF = .;
   IF (Q10B_RDF <= -1) THEN Q10B_RDF = .;
   IF (Q10C_RDF <= -1) THEN Q10C_RDF = .;
   IF (Q10A_ODD <= -1) THEN Q10A_ODD = .;
   IF (Q10B_ODD <= -1) THEN Q10B_ODD = .;
   IF (Q10C_ODD <= -1) THEN Q10C_ODD = .;
   IF (Q10A_ODM <= -1) THEN Q10A_ODM = .;
   IF (Q10B_ODM <= -1) THEN Q10B_ODM = .;
   IF (Q10C_ODM <= -1) THEN Q10C_ODM = .;
   IF (Q10A_ODF <= -1) THEN Q10A_ODF = .;
   IF (Q10B_ODF <= -1) THEN Q10B_ODF = .;
   IF (Q10C_ODF <= -1) THEN Q10C_ODF = .;
   IF (Q11_HDD <= -1) THEN Q11_HDD = .;
   IF (Q11_HDF <= -1) THEN Q11_HDF = .;
   IF (Q11_RDD <= -1) THEN Q11_RDD = .;
   IF (Q11_RDF <= -1) THEN Q11_RDF = .;
   IF (Q11_ODD <= -1) THEN Q11_ODD = .;
   IF (Q11_ODM <= -1) THEN Q11_ODM = .;
   IF (Q11_ODF <= -1) THEN Q11_ODF = .;
   IF (Q12A <= -1) THEN Q12A = .;
   IF (Q12B <= -1) THEN Q12B = .;
   IF (Q12C <= -1) THEN Q12C = .;
   IF (Q12D <= -1) THEN Q12D = .;
   IF (Q13A <= -1) THEN Q13A = .;
   IF (Q13A_TNS <= -1) THEN Q13A_TNS = .;
   IF (Q13B <= -1) THEN Q13B = .;
   IF (Q13B_PRG <= -1) THEN Q13B_PRG = .;
   IF (Q13C <= -1) THEN Q13C = .;
   IF (Q13C_IVD <= -1) THEN Q13C_IVD = .;
   IF (Q13D <= -1) THEN Q13D = .;
   IF (Q13D_DDC <= -1) THEN Q13D_DDC = .;
   IF (Q13E <= -1) THEN Q13E = .;
   IF (Q14A <= -1) THEN Q14A = .;
   IF (Q14B <= -1) THEN Q14B = .;
   IF (Q14C <= -1) THEN Q14C = .;
   IF (Q15_CERT <= -1) THEN Q15_CERT = .;
   IF (Q15A <= -1) THEN Q15A = .;
   IF (Q16_COMP <= -1) THEN Q16_COMP = .;
   IF (Q17A <= -1) THEN Q17A = .;
   IF (Q17B <= -1) THEN Q17B = .;
   IF (Q17C <= -1) THEN Q17C = .;
   IF (Q17D <= -1) THEN Q17D = .;
   IF (Q18_OWN <= -1) THEN Q18_OWN = .;
   IF (Q19A <= -1) THEN Q19A = .;
   IF (Q19B <= -1) THEN Q19B = .;
   IF (Q19C <= -1) THEN Q19C = .;
   IF (Q19D <= -1) THEN Q19D = .;
   IF (Q19E <= -1) THEN Q19E = .;
   IF (Q19F <= -1) THEN Q19F = .;
   IF (Q20A <= -1) THEN Q20A = .;
   IF (Q20B <= -1) THEN Q20B = .;
   IF (Q20C <= -1) THEN Q20C = .;
   IF (Q21_OTHU <= -1) THEN Q21_OTHU = .;
   IF (Q22_MULT <= -1) THEN Q22_MULT = .;
   IF (Q23A_1 <= -1) THEN Q23A_1 = .;
   IF (Q23A_2 <= -1) THEN Q23A_2 = .;
   IF (Q23A_3 <= -1) THEN Q23A_3 = .;
   IF (Q23A_4 <= -1) THEN Q23A_4 = .;
   IF (Q23A_5 <= -1) THEN Q23A_5 = .;
   IF (Q23B_1 <= -1) THEN Q23B_1 = .;
   IF (Q23B_2 <= -1) THEN Q23B_2 = .;
   IF (Q23B_3 <= -1) THEN Q23B_3 = .;
   IF (Q23B_4 <= -1) THEN Q23B_4 = .;
   IF (Q23B_5 <= -1) THEN Q23B_5 = .;
   IF (Q23C_1 <= -1) THEN Q23C_1 = .;
   IF (Q23C_2 <= -1) THEN Q23C_2 = .;
   IF (Q23C_3 <= -1) THEN Q23C_3 = .;
   IF (CORRFAC <= -1) THEN CORRFAC = .;
   IF (ALCHONLY <= -1) THEN ALCHONLY = .;
   IF (STRATUM <= -1) THEN STRATUM = .;
   IF (REGION <= -1) THEN REGION = .;
   IF (QA1 <= -1) THEN QA1 = .;
   IF (QA1A <= -1) THEN QA1A = .;
   IF (QA2 <= -1) THEN QA2 = .;
   IF (QA3 <= -1) THEN QA3 = .;
   IF (QA3A <= -1) THEN QA3A = .;
   IF (QA4 <= -1) THEN QA4 = .;
   IF (QA4A <= -1) THEN QA4A = .;
   IF (QA5 <= -1) THEN QA5 = .;
   IF (QA5A <= -1) THEN QA5A = .;
   IF (QA6 <= -1) THEN QA6 = .;
   IF (QA6A <= -1) THEN QA6A = .;
   IF (QB1 <= -1) THEN QB1 = .;
   IF (QB1A <= -1) THEN QB1A = .;
   IF (REP_STRA <= -1) THEN REP_STRA = .;
   IF (VWGHT <= -1.00000) THEN VWGHT = .;
   IF (VWT1 <= -1.00000) THEN VWT1 = .;
   IF (VWT2 <= -1.00000) THEN VWT2 = .;
   IF (VWT3 <= -1.00000) THEN VWT3 = .;
   IF (VWT4 <= -1.00000) THEN VWT4 = .;
   IF (VWT5 <= -1.00000) THEN VWT5 = .;
   IF (VWT6 <= -1.00000) THEN VWT6 = .;
   IF (VWT7 <= -1.00000) THEN VWT7 = .;
   IF (VWT8 <= -1.00000) THEN VWT8 = .;
   IF (VWT9 <= -1.00000) THEN VWT9 = .;
   IF (VWT10 <= -1.00000) THEN VWT10 = .;
   IF (VWT11 <= -1.00000) THEN VWT11 = .;
   IF (VWT12 <= -1.00000) THEN VWT12 = .;
   IF (VWT13 <= -1.00000) THEN VWT13 = .;
   IF (VWT14 <= -1.00000) THEN VWT14 = .;
   IF (VWT15 <= -1.00000) THEN VWT15 = .;
   IF (VWT16 <= -1.00000) THEN VWT16 = .;
   IF (VWT17 <= -1.00000) THEN VWT17 = .;
   IF (VWT18 <= -1.00000) THEN VWT18 = .;
   IF (VWT19 <= -1.00000) THEN VWT19 = .;
   IF (VWT20 <= -1.00000) THEN VWT20 = .;
   IF (VWT21 <= -1.00000) THEN VWT21 = .;
   IF (VWT22 <= -1.00000) THEN VWT22 = .;
   IF (VWT23 <= -1.00000) THEN VWT23 = .;
   IF (VWT24 <= -1.00000) THEN VWT24 = .;
   IF (VWT25 <= -1.00000) THEN VWT25 = .;
   IF (VWT26 <= -1.00000) THEN VWT26 = .;
   IF (VWT27 <= -1.00000) THEN VWT27 = .;
   IF (VWT28 <= -1.00000) THEN VWT28 = .;
   IF (VWT29 <= -1.00000) THEN VWT29 = .;
   IF (VWT30 <= -1.00000) THEN VWT30 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT Q1_COR q1_cor. Q2 q2ffffff. Q3_SEP q3_sep.
         Q4_DIF q4_dif. Q5_DRUG q5_drug. Q5_ALC q5_alc.
         Q6_COR q6_cor. Q6A q6a. Q7_COR q7_cor.
         Q7A q7a. Q8 q8ffffff. Q9 q9ffffff.
         Q10A_HDD q10a_hdd. Q10B_HDD q10b_hdd. Q10C_HDD q10c_hdd.
         Q10A_HDF q10a_hdf. Q10B_HDF q10b_hdf. Q10C_HDF q10c_hdf.
         Q10A_RDD q10a_rdd. Q10B_RDD q10b_rdd. Q10C_RDD q10c_rdd.
         Q10A_RDF q10a_rdf. Q10B_RDF q10b_rdf. Q10C_RDF q10c_rdf.
         Q10A_ODD q10a_odd. Q10B_ODD q10b_odd. Q10C_ODD q10c_odd.
         Q10A_ODM q10a_odm. Q10B_ODM q10b_odm. Q10C_ODM q10c_odm.
         Q10A_ODF q10a_odf. Q10B_ODF q10b_odf. Q10C_ODF q10c_odf.
         Q11_HDD q11_hdd. Q11_HDF q11_hdf. Q11_RDD q11_rdd.
         Q11_RDF q11_rdf. Q11_ODD q11_odd. Q11_ODM q11_odm.
         Q11_ODF q11_odf. Q12A q12a. Q12B q12b.
         Q12C q12c. Q12D q12d. Q13A q13a.
         Q13A_TNS q13a_tns. Q13B q13b. Q13B_PRG q13b_prg.
         Q13C q13c. Q13C_IVD q13c_ivd. Q13D q13d.
         Q13D_DDC q13d_ddc. Q13E q13e. Q14A q14a.
         Q14B q14b. Q14C q14c. Q15_CERT q15_cert.
         Q15A q15a. Q16_COMP q16_comp. Q17A q17a.
         Q17B q17b. Q17C q17c. Q17D q17d.
         Q18_OWN q18_own. Q19A q19a. Q19B q19b.
         Q19C q19c. Q19D q19d. Q19E q19e.
         Q19F q19f. Q20A q20a. Q20B q20b.
         Q20C q20c. Q21_OTHU q21_othu. Q22_MULT q22_mult.
         Q23A_1 q23a_1ff. Q23A_2 q23a_2ff. Q23A_3 q23a_3ff.
         Q23A_4 q23a_4ff. Q23A_5 q23a_5ff. Q23B_1 q23b_1ff.
         Q23B_2 q23b_2ff. Q23B_3 q23b_3ff. Q23B_4 q23b_4ff.
         Q23B_5 q23b_5ff. Q23C_1 q23c_1ff. Q23C_2 q23c_2ff.
         Q23C_3 q23c_3ff. CORRFAC corrfac. ALCHONLY alchonly.
         STRATUM stratum. REGION region. QA1 qa1fffff.
         QA1A qa1a. QA2 qa2fffff. QA3 qa3fffff.
         QA3A qa3a. QA4 qa4fffff. QA4A qa4a.
         QA5 qa5fffff. QA5A qa5a. QA6 qa6fffff.
         QA6A qa6a. QB1 qb1fffff. QB1A qb1a.
          ;
*/

RUN ;
